@@ -137,12 +137,26 @@ def exists(file_path, **kwargs):
         ----------
         `return` {bool}
             True if the file exists, False otherwise.
+
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 12-17-2021 17:15:22
+        `memberOf`: file
+        `version`: 1.1
+        `method_name`: exists
+
+
+        Changes
+        ----------
+        12\\17\\2021 17:16:04 - 1.1 - typo on isFile function call.
     '''
 
     ftp = obj.get_kwarg(["ftp"], None, None, **kwargs)
 
     if ftp is not None:
-        if ftp.path.isFile(file_path):
+        if ftp.path.isfile(file_path):
             if ftp.path.exists(file_path):
                 return True
         return False
@@ -378,6 +392,10 @@ def copy(src, dest=False, **kwargs):
         [`min_thread_threshold`=100] {int}
             There must be this many files to copy before threading is allowed.
 
+        [`ftp`=None] {object}
+            A reference to the ftputil object to use.
+
+
         Return {type}
         ----------------------
         return_description
@@ -390,7 +408,7 @@ def copy(src, dest=False, **kwargs):
         `version`: 1.0
         `method_name`: copy
     '''
-
+    ftp = obj.get_kwarg(["ftp"], None, None, **kwargs)
     threading = obj.get_kwarg(["threading"], True, (bool), **kwargs)
     max_threads = obj.get_kwarg(["max_threads"], 15, (int), **kwargs)
     min_thread_threshold = obj.get_kwarg(["min thread threshold", "min files thread"], 100, (int), **kwargs)
@@ -416,19 +434,22 @@ def copy(src, dest=False, **kwargs):
             _thread_file_action(copy_list, action="copy", max_threads=max_threads, min_thread_threshold=min_thread_threshold)
             return
 
-    _copy_files_from_array(copy_list)
+    _copy_files_from_array(copy_list, ftp)
     # print(f"copy_list: {copy_list}")
 
 
-def _copy_files_from_array(file_list, attempted_delete=False):
+def _copy_files_from_array(file_list, ftp=None, attempted_delete=False):
     for file in file_list:
         try:
+            if ftp is not None:
+                ftp.upload_if_newer(file['src_path'], file['dst_path'])
+                continue
             os.makedirs(os.path.dirname(file['dst_path']), exist_ok=True)
             shutil.copy2(file['src_path'], file['dst_path'])
         except PermissionError as error:
             if attempted_delete is False:
                 _delete_single_file(file['dst_path'])
-                _copy_files_from_array([file], True)
+                _copy_files_from_array([file], ftp, True)
             else:
                 print(f"Failed to copy file: {file['src_path']} to {file['dst_path']}.\n{error}")
                 print(traceback.format_exc())
